# Tic Tac Toe with AI
[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   

## Discription
This is a simple command-line implementation of the Tic Tac Toe game in Python, where you can play against an AI opponent. The AI opponent uses the minimax algorithm to make its moves, providing a challenging gameplay experience.

## Usage

- Make sure you have Python installed in your system.
- Run Following command in the Terminal.
 ```
  pip install TicTacToeAI
  ```
## Example

 ```
# test.py
import TicTacToeAI

## To run

# For easy level of game.
run = TicTacToeAI.play_game() 

# For medium level of game.
run = TicTacToeAI.play_game('medium')

# For hard level of game.
run = TicTacToeAI.play_game('hard')

```

## Run the following Script.
 ```
  python test.py
 ```

## Note 
- I have tried to implement all the functionality, it might have some bugs also. Ignore that or please try to solve that bug.

